@@ -44,9 +44,9 @@ fn match_get() {
         .unwrap();
 
     // match the second route
-    let router = router![bar_baz_qux, foo_bar_baz];
+    let routes = routes![bar_baz_qux, foo_bar_baz];
 
-    let response = match router(request) {
+    let response = match router(request, routes) {
         RouterResult::Handled(response) => response,
         RouterResult::NotHandled(_) => panic!("should have been handled!"),
     };
@@ -61,9 +61,9 @@ fn match_get_with_arg() {
         .body(String::new())
         .unwrap();
 
-    let router = router![bar_baz_qux, foo_bar_baz];
+    let routes = routes![bar_baz_qux, foo_bar_baz];
 
-    let response = match router(request) {
+    let response = match router(request, routes) {
         RouterResult::Handled(response) => response,
         RouterResult::NotHandled(_) => panic!("should have been handled!"),
     };
@@ -78,9 +78,9 @@ fn match_wildcard() {
         .body(String::new())
         .unwrap();
 
-    let router = router![wild_foo_bar];
+    let routes = routes![wild_foo_bar];
 
-    let response = match router(request) {
+    let response = match router(request, routes) {
         RouterResult::Handled(response) => response,
         RouterResult::NotHandled(_) => panic!("should have been handled!"),
     };
@@ -95,9 +95,9 @@ fn match_glob() {
         .body(String::new())
         .unwrap();
 
-    let router = router![glob];
+    let routes = routes![glob];
 
-    let response = match router(request) {
+    let response = match router(request, routes) {
         RouterResult::Handled(response) => response,
         RouterResult::NotHandled(_) => panic!("should have been handled!"),
     };
@@ -112,9 +112,9 @@ fn match_glob_foo() {
         .body(String::new())
         .unwrap();
 
-    let router = router![glob];
+    let routes = routes![glob];
 
-    let response = match router(request) {
+    let response = match router(request, routes) {
         RouterResult::Handled(response) => response,
         RouterResult::NotHandled(_) => panic!("should have been handled!"),
     };
